/* eslint no-param-reassign: 0 */
import Color from 'color';
import { css } from 'styled-components';
import { colorYiq, rgba, mix } from '../util';

var focusBoxShadow = function focusBoxShadow(background, border, boxShadow) {
  return function (_ref) {
    var theme = _ref.theme;

    if (theme.bootstrap.enableShadows) {
      return css(["box-shadow:", ",0 0 0 ", " ", ";"], boxShadow, theme.bootstrap.variables.btnFocusWidth, rgba(mix(colorYiq(background), border, 0.15), 0.5));
    }

    return css(["box-shadow:0 0 0 ", " ", ";"], theme.bootstrap.variables.btnFocusWidth, rgba(mix(colorYiq(background), border, 0.15), 0.5));
  };
};

export var buttonVariant = function buttonVariant(background, border, hoverBackground, hoverBorder, activeBackground, activeBorder) {
  hoverBackground = hoverBackground || Color(background).darken(0.075).string();
  hoverBorder = hoverBorder || Color(border).darken(0.1).string();
  activeBackground = activeBackground || Color(background).darken(0.1).string();
  activeBorder = activeBorder || Color(border).darken(0.125).string();
  return function (_ref2) {
    var theme = _ref2.theme;
    return css(["color:", ";", ";border-color:", ";", ";&:hover{color:", ";", ";border-color:", ";}&:focus,&.focus{color:", ";", ";border-color:", ";", ";}&.disabled,&:disabled{color:", ";background-color:", ";border-color:", ";", ";}&:not(:disabled):not(.disabled):active,&:not(:disabled):not(.disabled).active,.show > &.dropdown-toggle{color:", ";background-color:", ";", ";border-color:", ";&:focus{", ";}}"], colorYiq(background), theme.bootstrap.gradientBg(background), border, theme.bootstrap.boxShadow(theme.bootstrap.variables.btnBoxShadow), colorYiq(hoverBackground), theme.bootstrap.gradientBg(hoverBackground), hoverBorder, colorYiq(hoverBackground), theme.bootstrap.gradientBg(hoverBackground), hoverBorder, focusBoxShadow(background, border, theme.bootstrap.variables.btnBoxShadow), colorYiq(background), background, border, theme.bootstrap.enableGradients ? 'background-image: none' : '', colorYiq(activeBackground), activeBackground, theme.bootstrap.enableGradients ? 'background-image: none' : '', activeBorder, focusBoxShadow(background, border, theme.bootstrap.variables.btnActiveBoxShadow));
  };
};

var outlineFocusBoxShadow = function outlineFocusBoxShadow(color) {
  return function (_ref3) {
    var theme = _ref3.theme;

    if (theme.bootstrap.enableShadows && theme.bootstrap.variables.btnActiveBoxShadow) {
      return css(["box-shadow:", ",0 0 0 ", " ", ";"], theme.bootstrap.variables.btnActiveBoxShadow, theme.bootstrap.variables.btnFocusWidth, rgba(color, 0.5));
    }

    return css(["box-shadow:0 0 0 ", " ", ";"], theme.bootstrap.variables.btnFocusWidth, rgba(color, 0.5));
  };
};

export var buttonOutlineVariant = function buttonOutlineVariant(color, colorHover, activeBackground, activeBorder) {
  colorHover = colorHover || colorYiq(color);
  activeBackground = activeBackground || color;
  activeBorder = activeBorder || color;
  return function (_ref4) {
    var theme = _ref4.theme;
    return css(["color:", ";border-color:", ";&:hover{color:", ";background-color:", ";border-color:", ";}&:focus,&.focus{box-shadow:0 0 0 ", " ", ";}&.disabled,&:disabled{color:", ";background-color:transparent;}&:not(:disabled):not(.disabled):active,&:not(:disabled):not(.disabled).active,.show > &.dropdown-toggle{color:", ";background-color:", ";border-color:", ";&:focus{", ";}}"], color, color, colorHover, activeBackground, activeBorder, theme.bootstrap.variables.btnFocusWidth, rgba(color, 0.5), color, colorYiq(activeBackground), activeBackground, activeBorder, outlineFocusBoxShadow(color));
  };
};
export var buttonSize = function buttonSize(paddingY, paddingX, fontSize, lineHeight, borderRadius) {
  return function (_ref5) {
    var theme = _ref5.theme;
    return css(["padding:", " ", ";", ";line-height:", ";", ";"], paddingY, paddingX, theme.bootstrap.fontSize(fontSize), lineHeight, theme.bootstrap.borderRadius(borderRadius, 0));
  };
};