import Color from 'color';
import { rgba } from './util'; // Color system

export var white = '#fff';
export var gray100 = '#f8f9fa';
export var gray200 = '#e9ecef';
export var gray300 = '#dee2e6';
export var gray400 = '#ced4da';
export var gray500 = '#adb5bd';
export var gray600 = '#6c757d';
export var gray700 = '#495057';
export var gray800 = '#343a40';
export var gray900 = '#212529';
export var black = '#000';
export var blue = '#007bff';
export var indigo = '#6610f2';
export var purple = '#6f42c1';
export var pink = '#e83e8c';
export var red = '#dc3545';
export var orange = '#fd7e14';
export var yellow = '#ffc107';
export var green = '#28a745';
export var teal = '#20c997';
export var cyan = '#17a2b8';
export var primary = blue;
export var secondary = gray600;
export var success = green;
export var info = cyan;
export var warning = yellow;
export var danger = red;
export var light = gray100;
export var dark = gray800;
export var themeColor = {
  primary: primary,
  secondary: secondary,
  success: success,
  info: info,
  warning: warning,
  danger: danger,
  light: light,
  dark: dark
}; // The yiq lightness value that determines when the lightness of color changes from
// "dark" to "light". Acceptable values are between 0 and 255.

export var yiqContrastedThreshold = 150; // Customize the light and dark text colors for use in our YIQ color contrast function.

export var yiqTextDark = gray900;
export var yiqTextLight = white; // Spacing
//
// Control the default styling of most Bootstrap elements by modifying these
// variables. Mostly focused on spacing.
// You can add more entries to the $spacers map, should you need more variation.

export var spacer = 1;
export var spacerUnits = 'rem';
export var spacers = {
  0: 0,
  1: spacer * 0.25,
  2: spacer * 0.5,
  3: spacer,
  4: spacer * 1.5,
  5: spacer * 3
}; // $negative-spacers: negativify-map($spacers) !default; // TODO
// Body
//
// Settings for the `<body>` element.

export var bodyBg = white;
export var bodyColor = gray900; // Links
//
// Style anchor elements.

export var linkColor = themeColor.primary;
export var linkDecoration = 'none';
export var linkHoverColor = Color(linkColor).darken(0.15).string();
export var linkHoverDecoration = 'underline'; // Darken percentage for links with `.text-*` class (e.g. `.text-success`)

export var emphasizedLinkHoverDarkenPercentage = '15%'; // Components
//
// Define common padding and border radius sizes and more.

export var lineHeightLg = 1.5;
export var lineHeightSm = 1.5;
export var borderWidth = '1px';
export var borderColor = gray300;
export var borderRadius = '.25rem';
export var borderRadiusLg = '.3rem';
export var borderRadiusSm = '.2rem';
export var roundedPill = '50rem';
export var boxShadowSm = "0 .125rem .25rem " + rgba(black, 0.075);
export var boxShadow = "0 .5rem 1rem " + rgba(black, 0.15);
export var boxShadowLg = "0 1rem 3rem " + rgba(black, 0.175);
export var componentActiveColor = white;
export var componentActiveBg = themeColor.primary;
export var caretWidth = 0.3;
export var caretWidthUnits = 'em';
export var caretVerticalAlign = caretWidth * 0.85;
export var caretSpacing = caretWidth * 0.85;
export var transitionBase = 'all .2s ease-in-out';
export var transitionFade = 'opacity .15s linear';
export var transitionCollapse = 'height .35s ease'; // Typography
//
// Font, line-height, and color for body text, headings, and more.
// stylelint-disable value-keyword-case

export var fontFamilySansSerif = '-apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, "Noto Sans", sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji"';
export var fontFamilyMonospace = 'SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace';
export var fontFamilyBase = fontFamilySansSerif; // stylelint-enable value-keyword-case
// Assumes the browser default, typically `16px`

export var fontSizeBase = 1;
export var fontSizeUnits = 'rem';
export var fontSizeLg = "" + fontSizeBase * 1.25 + fontSizeUnits;
export var fontSizeSm = "" + fontSizeBase * 0.875 + fontSizeUnits;
export var fontWeightLighter = 'lighter';
export var fontWeightLight = 300;
export var fontWeightNormal = 400;
export var fontWeightBold = 700;
export var fontWeightBolder = 'bolder';
export var fontWeightBase = fontWeightNormal;
export var lineHeightBase = 1.5;
export var h1FontSize = "" + fontSizeBase * 2.5 + fontSizeUnits;
export var h2FontSize = "" + fontSizeBase * 2 + fontSizeUnits;
export var h3FontSize = "" + fontSizeBase * 1.75 + fontSizeUnits;
export var h4FontSize = "" + fontSizeBase * 1.5 + fontSizeUnits;
export var h5FontSize = "" + fontSizeBase * 1.25 + fontSizeUnits;
export var h6FontSize = "" + fontSizeBase + fontSizeUnits;
export var headingsMarginBottom = spacer / 2;
export var headingsFontFamily = null;
export var headingsFontStyle = null;
export var headingsFontWeight = 500;
export var headingsLineHeight = 1.2;
export var headingsColor = null;
export var display1Size = '6rem';
export var display2Size = '5.5rem';
export var display3Size = '4.5rem';
export var display4Size = '3.5rem';
export var display1Weight = 300;
export var display2Weight = 300;
export var display3Weight = 300;
export var display4Weight = 300;
export var displayLineHeight = headingsLineHeight;
export var leadFontSize = "" + fontSizeBase * 1.25 + fontSizeUnits;
export var leadFontWeight = 300;
export var smallFontSize = '80%';
export var textMuted = gray600;
export var blockquoteSmallColor = gray600;
export var blockquoteSmallFontSize = smallFontSize;
export var blockquoteFontSize = "" + fontSizeBase * 1.25 + fontSizeUnits;
export var hrColor = 'inherit';
export var hrHeight = borderWidth;
export var hrOpacity = 0.25;
export var markPadding = '.2em';
export var dtFontWeight = fontWeightBold;
export var kbdBoxShadow = "inset 0 .1rem 0 " + rgba(black, 0.25);
export var nestedKbdFontWeight = fontWeightBold;
export var listInlinePadding = '.5rem';
export var markBg = '#fcf8e3';
export var hrMarginY = spacer; // Buttons + Forms
//
// Shared variables that are reassigned to `$input-` and `$btn-` specific variables.

export var inputBtnPaddingY = '.375rem';
export var inputBtnPaddingX = '.75rem';
export var inputBtnFontFamily = null;
export var inputBtnFontSize = "" + fontSizeBase + fontSizeUnits;
export var inputBtnLineHeight = lineHeightBase;
export var inputBtnFocusWidth = '.2rem';
export var inputBtnFocusColor = rgba(componentActiveBg, 0.25);
export var inputBtnFocusBoxShadow = "0 0 0 " + inputBtnFocusWidth + " " + inputBtnFocusColor;
export var inputBtnPaddingYSm = '.25rem';
export var inputBtnPaddingXSm = '.5rem';
export var inputBtnFontSizeSm = fontSizeSm;
export var inputBtnLineHeightSm = lineHeightSm;
export var inputBtnPaddingYLg = '.5rem';
export var inputBtnPaddingXLg = '1rem';
export var inputBtnFontSizeLg = fontSizeLg;
export var inputBtnLineHeightLg = lineHeightLg;
export var inputBtnBorderWidth = borderWidth; // Buttons
//
// For each of Bootstrap's buttons, define text, background, and border color.

export var btnPaddingY = inputBtnPaddingY;
export var btnPaddingX = inputBtnPaddingX;
export var btnFontFamily = inputBtnFontFamily;
export var btnFontSize = inputBtnFontSize;
export var btnLineHeight = inputBtnLineHeight;
export var btnPaddingYSm = inputBtnPaddingYSm;
export var btnPaddingXSm = inputBtnPaddingXSm;
export var btnFontSizeSm = inputBtnFontSizeSm;
export var btnLineHeightSm = inputBtnLineHeightSm;
export var btnPaddingYLg = inputBtnPaddingYLg;
export var btnPaddingXLg = inputBtnPaddingXLg;
export var btnFontSizeLg = inputBtnFontSizeLg;
export var btnLineHeightLg = inputBtnLineHeightLg;
export var btnBorderWidth = inputBtnBorderWidth;
export var btnFontWeight = fontWeightNormal;
export var btnBoxShadow = "inset 0 1px 0 " + rgba(white, 0.15) + ", 0 1px 1px " + rgba(black, 0.075);
export var btnFocusWidth = inputBtnFocusWidth;
export var btnFocusBoxShadow = inputBtnFocusBoxShadow;
export var btnDisabledOpacity = 0.65;
export var btnActiveBoxShadow = "inset 0 3px 5px " + rgba(black, 0.125);
export var btnLinkColor = linkColor;
export var btnLinkHoverColor = linkHoverColor;
export var btnLinkDisabledColor = gray600;
export var btnBlockSpacingY = '.5rem'; // Allows for customizing button radius independently from global border radius

export var btnBorderRadius = borderRadius;
export var btnBorderRadiusLg = borderRadiusLg;
export var btnBorderRadiusSm = borderRadiusSm;
export var btnTransition = 'color .15s ease-in-out, background-color .15s ease-in-out, border-color .15s ease-in-out, box-shadow .15s ease-in-out';