"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.buttonSize = exports.buttonOutlineVariant = exports.buttonVariant = void 0;

var _color = _interopRequireDefault(require("color"));

var _styledComponents = require("styled-components");

var _util = require("../util");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint no-param-reassign: 0 */
var focusBoxShadow = function focusBoxShadow(background, border, boxShadow) {
  return function (_ref) {
    var theme = _ref.theme;

    if (theme.bootstrap.enableShadows) {
      return (0, _styledComponents.css)(["box-shadow:", ",0 0 0 ", " ", ";"], boxShadow, theme.bootstrap.variables.btnFocusWidth, (0, _util.rgba)((0, _util.mix)((0, _util.colorYiq)(background), border, 0.15), 0.5));
    }

    return (0, _styledComponents.css)(["box-shadow:0 0 0 ", " ", ";"], theme.bootstrap.variables.btnFocusWidth, (0, _util.rgba)((0, _util.mix)((0, _util.colorYiq)(background), border, 0.15), 0.5));
  };
};

var buttonVariant = function buttonVariant(background, border, hoverBackground, hoverBorder, activeBackground, activeBorder) {
  hoverBackground = hoverBackground || (0, _color.default)(background).darken(0.075).string();
  hoverBorder = hoverBorder || (0, _color.default)(border).darken(0.1).string();
  activeBackground = activeBackground || (0, _color.default)(background).darken(0.1).string();
  activeBorder = activeBorder || (0, _color.default)(border).darken(0.125).string();
  return function (_ref2) {
    var theme = _ref2.theme;
    return (0, _styledComponents.css)(["color:", ";", ";border-color:", ";", ";&:hover{color:", ";", ";border-color:", ";}&:focus,&.focus{color:", ";", ";border-color:", ";", ";}&.disabled,&:disabled{color:", ";background-color:", ";border-color:", ";", ";}&:not(:disabled):not(.disabled):active,&:not(:disabled):not(.disabled).active,.show > &.dropdown-toggle{color:", ";background-color:", ";", ";border-color:", ";&:focus{", ";}}"], (0, _util.colorYiq)(background), theme.bootstrap.gradientBg(background), border, theme.bootstrap.boxShadow(theme.bootstrap.variables.btnBoxShadow), (0, _util.colorYiq)(hoverBackground), theme.bootstrap.gradientBg(hoverBackground), hoverBorder, (0, _util.colorYiq)(hoverBackground), theme.bootstrap.gradientBg(hoverBackground), hoverBorder, focusBoxShadow(background, border, theme.bootstrap.variables.btnBoxShadow), (0, _util.colorYiq)(background), background, border, theme.bootstrap.enableGradients ? 'background-image: none' : '', (0, _util.colorYiq)(activeBackground), activeBackground, theme.bootstrap.enableGradients ? 'background-image: none' : '', activeBorder, focusBoxShadow(background, border, theme.bootstrap.variables.btnActiveBoxShadow));
  };
};

exports.buttonVariant = buttonVariant;

var outlineFocusBoxShadow = function outlineFocusBoxShadow(color) {
  return function (_ref3) {
    var theme = _ref3.theme;

    if (theme.bootstrap.enableShadows && theme.bootstrap.variables.btnActiveBoxShadow) {
      return (0, _styledComponents.css)(["box-shadow:", ",0 0 0 ", " ", ";"], theme.bootstrap.variables.btnActiveBoxShadow, theme.bootstrap.variables.btnFocusWidth, (0, _util.rgba)(color, 0.5));
    }

    return (0, _styledComponents.css)(["box-shadow:0 0 0 ", " ", ";"], theme.bootstrap.variables.btnFocusWidth, (0, _util.rgba)(color, 0.5));
  };
};

var buttonOutlineVariant = function buttonOutlineVariant(color, colorHover, activeBackground, activeBorder) {
  colorHover = colorHover || (0, _util.colorYiq)(color);
  activeBackground = activeBackground || color;
  activeBorder = activeBorder || color;
  return function (_ref4) {
    var theme = _ref4.theme;
    return (0, _styledComponents.css)(["color:", ";border-color:", ";&:hover{color:", ";background-color:", ";border-color:", ";}&:focus,&.focus{box-shadow:0 0 0 ", " ", ";}&.disabled,&:disabled{color:", ";background-color:transparent;}&:not(:disabled):not(.disabled):active,&:not(:disabled):not(.disabled).active,.show > &.dropdown-toggle{color:", ";background-color:", ";border-color:", ";&:focus{", ";}}"], color, color, colorHover, activeBackground, activeBorder, theme.bootstrap.variables.btnFocusWidth, (0, _util.rgba)(color, 0.5), color, (0, _util.colorYiq)(activeBackground), activeBackground, activeBorder, outlineFocusBoxShadow(color));
  };
};

exports.buttonOutlineVariant = buttonOutlineVariant;

var buttonSize = function buttonSize(paddingY, paddingX, fontSize, lineHeight, borderRadius) {
  return function (_ref5) {
    var theme = _ref5.theme;
    return (0, _styledComponents.css)(["padding:", " ", ";", ";line-height:", ";", ";"], paddingY, paddingX, theme.bootstrap.fontSize(fontSize), lineHeight, theme.bootstrap.borderRadius(borderRadius, 0));
  };
};

exports.buttonSize = buttonSize;